"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeResetSequnceNumberInstruction = exports.makeCheckAndSetSequenceNumberInstruction = exports.makeInitSequenceInstruction = void 0;
const web3_js_1 = require("@solana/web3.js");
const bn_js_1 = __importDefault(require("bn.js"));
const crypto_1 = require("crypto");
function makeInitSequenceInstruction(sequenceAccount, ownerPk, bump, sym, programId) {
    const keys = [
        { isSigner: false, isWritable: true, pubkey: sequenceAccount },
        { isSigner: true, isWritable: true, pubkey: ownerPk },
        { isSigner: false, isWritable: false, pubkey: web3_js_1.SystemProgram.programId }
    ];
    const variant = (0, crypto_1.createHash)('sha256')
        .update('global:initialize')
        .digest()
        .slice(0, 8);
    const bumpData = new bn_js_1.default(bump).toBuffer('le', 1);
    const strLen = new bn_js_1.default(sym.length).toBuffer('le', 4);
    const symEncoded = Buffer.from(sym);
    const data = Buffer.concat([variant, bumpData, strLen, symEncoded]);
    return new web3_js_1.TransactionInstruction({
        keys,
        data,
        programId
    });
}
exports.makeInitSequenceInstruction = makeInitSequenceInstruction;
function makeCheckAndSetSequenceNumberInstruction(sequenceAccount, ownerPk, seqNum, programId) {
    const keys = [
        { isSigner: false, isWritable: true, pubkey: sequenceAccount },
        { isSigner: true, isWritable: false, pubkey: ownerPk }
    ];
    const variant = (0, crypto_1.createHash)('sha256')
        .update('global:check_and_set_sequence_number')
        .digest()
        .slice(0, 8);
    const seqNumBuffer = new bn_js_1.default(seqNum).toBuffer('le', 8);
    const data = Buffer.concat([variant, seqNumBuffer]);
    return new web3_js_1.TransactionInstruction({
        keys,
        data,
        programId
    });
}
exports.makeCheckAndSetSequenceNumberInstruction = makeCheckAndSetSequenceNumberInstruction;
function makeResetSequnceNumberInstruction(sequenceAccount, ownerPk, seqNum, programId) {
    const keys = [
        { isSigner: false, isWritable: true, pubkey: sequenceAccount },
        { isSigner: true, isWritable: false, pubkey: ownerPk }
    ];
    const variant = (0, crypto_1.createHash)('sha256')
        .update('global:reset_sequence_number')
        .digest()
        .slice(0, 8);
    const seqNumBuffer = new bn_js_1.default(seqNum).toBuffer('le', 8);
    const data = Buffer.concat([variant, seqNumBuffer]);
    return new web3_js_1.TransactionInstruction({
        keys,
        data,
        programId
    });
}
exports.makeResetSequnceNumberInstruction = makeResetSequnceNumberInstruction;
//# sourceMappingURL=sequenceEnforcerProgram.js.map